@@ -24,6 +24,8 @@ class ESAMatrix:
         mat.eliminate_zeros()
         return mat
 
+    def get_mat(self):
+        return self._mat
 
     def get_terms(self):
         return self._terms
